diff scripts/plot/print.m @ 11252:d048ce3f7cef

Replace "delete" with "del" in DOS shell commands.
author Michael Goffioul <michael.goffioul@gmail.com>
date Sun, 14 Nov 2010 22:01:45 +0000
parents a44f979a35ce
children 093c9facf0f0
line wrap: on
line diff
--- a/scripts/plot/print.m	Sun Nov 14 21:57:19 2010 +0000
+++ b/scripts/plot/print.m	Sun Nov 14 22:01:45 2010 +0000
@@ -400,7 +400,7 @@
   ## output must be piped.
 
   ## DOS Shell:
   ##   copy con <filein> & epstool -bbox -preview-tiff <filein> <fileout> & delete <filein>
   ## Unix Shell;
   ##   cat > <filein> ; epstool -bbox -preview-tiff <filein> <fileout> ; rm <filein>
 
@@ -417,7 +417,7 @@
     pipein = true;
     filein = strcat (tmpnam (), ".eps");
     if (dos_shell)
-      cleanup = sprintf ("& delete %s ", filein);
+      cleanup = sprintf ("& del %s ", strrep (filein, '/', '\'));
     else
       cleanup = sprintf ("; rm %s ", filein);
     endif
@@ -429,7 +429,7 @@
     pipeout = true;
     fileout = strcat (tmpnam (), ".eps");
     if (dos_shell)
-      cleanup = horzcat (cleanup, sprintf ("& delete %s ", fileout));
+      cleanup = horzcat (cleanup, sprintf ("& del %s ", strrep (fileout, '/', '\')));
     else
       cleanup = horzcat (cleanup, sprintf ("; rm %s ", fileout));
     endif
@@ -400,7 +400,7 @@
 
   ## DOS Shell:
-  ##   copy con <filein> & epstool -bbox -preview-tiff <filein> <fileout> & delete <filein>
+  ##   copy con <filein> & epstool -bbox -preview-tiff <filein> <fileout> & del <filein>
   ## Unix Shell;
   ##   cat > <filein> ; epstool -bbox -preview-tiff <filein> <fileout> ; rm <filein>